#ifndef NT2_INCLUDE_CONSTANTS_FOURTHROOTEPS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FOURTHROOTEPS_HPP_INCLUDED

#include <nt2/constant/include/constants/fourthrooteps.hpp>

#endif
